# video blur background

Convert horizontal video to 9:16 vertical video with blurred background filling the empty space

## install

```sh
pip install bgblur
```

## How to use

```sh
bgblur -i "input video file path" -o "output video file path"
```
